@@ -61,10 +61,12 @@ typedef struct
  */
 extern PyTypeObject sipMethodDescr_Type;
 PyObject *sipMethodDescr_New(PyMethodDef *pmd);
+PyObject *sipMethodDescr_Copy(PyObject *orig, PyObject *mixin_name);
 
 extern PyTypeObject sipVariableDescr_Type;
 PyObject *sipVariableDescr_New(sipVariableDef *vd, const sipTypeDef *td,
     const sipContainerDef *cod);
+PyObject *sipVariableDescr_Copy(PyObject *orig, PyObject *mixin_name);
 
 
 /*
@@ -112,7 +114,10 @@ PyObject *sip_api_convert_from_type(void *cppPtr, const sipTypeDef *td,
         PyObject *transferObj);
 void sip_api_common_dtor(sipSimpleWrapper *sipSelf);
 void sip_api_end_thread(void);
+void *sip_api_force_convert_to_type(PyObject *pyObj, const sipTypeDef *td,
+        PyObject *transferObj, int flags, int *statep, int *iserrp);
 void sip_api_free_sipslot(sipSlot *slot);
+unsigned long sip_api_long_as_unsigned_long(PyObject *o);
 int sip_api_same_slot(const sipSlot *sp, PyObject *rxObj, const char *slot);
 PyObject *sip_api_invoke_slot(const sipSlot *slot, PyObject *sigargs);
 void *sip_api_convert_rx(sipWrapper *txSelf, const char *sigargs,
@@ -128,8 +133,8 @@ sipClassTypeDef *sipGetGeneratedClassType(sipEncodedTypeDef *enc,
 void sipSaveMethod(sipPyMethod *pm,PyObject *meth);
 int sipGetPending(void **pp, sipWrapper **op, int *fp);
 int sipIsPending();
-PyObject *sipWrapSimpleInstance(void *cppPtr, const sipTypeDef *td,
-        sipWrapper *owner, int initflags);
+PyObject *sipWrapInstance(void *cpp,  PyTypeObject *py_type, PyObject *args,
+        sipWrapper *owner, int flags);
 void *sipConvertRxEx(sipWrapper *txSelf, const char *sigargs,
         PyObject *rxObj, const char *slot, const char **memberp, int flags);
 
